#
# spec file for package python-dtfabric
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define modname dtfabric
Name:           python-dtfabric
Version:        20230520
Release:        1.4
Summary:        Data type fabric (dtfabric)
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/libyal/dtfabric
Source:         https://github.com/libyal/dtfabric/releases/download/%{version}/dtfabric-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-pip
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
dtFabric, or data type fabric, is a project to manage data types and structures, as used in the libyal projects.

%prep
%setup -q -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/validate-definitions.py
# setup.py install helpfully installs files where it shouldn’t
rm -rv %{buildroot}%{_datadir}/doc/%{modname}

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative validate-definitions.py

%postun
%python_uninstall_alternative validate-definitions.py

%check
# Using pytest leads to some horribly-looking crashes, not sure what's
# going on.
%python_exec ./run_tests.py

%files %{python_files}
%license LICENSE
%doc ACKNOWLEDGEMENTS AUTHORS README
%python_alternative %{_bindir}/validate-definitions.py
%{python_sitelib}/dtfabric
%{python_sitelib}/dtfabric-%{version}*-info

%changelog
* Sat Jan 27 2024 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to version 20230520
  * No changelog was provided.
- Add BuildRequires: python-setuptools -- build was failing without it
- Add Requires: python-pip -- lint check requested it
  - - not sure I did this properly; still getting lint errors.
* Sun Jul 30 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Sun Jul 30 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%sle15_python_module_pythons
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 20221218:
  * Auto-generated
* Wed Jun  8 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
- rm explict BuildRequires python38 to allow this to build on older releases of openSUSE
* Tue May 31 2022 Greg Freemyer <Greg.Freemyer@gmail.com>
-update to 20220219
  * No changelog was provided.
-update source to refer to github which is where dtfabric is developed
-remove tests-improved.patch
  * incorporated into upstream, no longer needed/applies
* Fri Jul 30 2021 Matej Cepl <mcepl@suse.com>
- Add tests-improved.patch gh#libyal/dtfabric#25
* Fri Mar 12 2021 Matej Cepl <mcepl@suse.com>
- Update to 20200621 release
  * No changelog was provided.
* Fri Mar 12 2021 Matej Cepl <mcepl@suse.com>
- Setup use of update-alternatives for the package binary.
* Fri Jan 17 2020 Matej Cepl <mcepl@suse.com>
- Initial effort to package dtfabric 20190120
